# Onboarding Journey
### On this page
  * [Overview](https://help.sap.com/docs/leanix/ea/onboarding-journey#overview)
  * [What You'll Achieve](https://help.sap.com/docs/leanix/ea/onboarding-journey#what-you'll-achieve)
  * [How to Get Started](https://help.sap.com/docs/leanix/ea/onboarding-journey#how-to-get-started)
  * [Who to Involve](https://help.sap.com/docs/leanix/ea/onboarding-journey#who-to-involve)
  * [Resources and Support](https://help.sap.com/docs/leanix/ea/onboarding-journey#resources-and-support)


Understand the objectives and key steps of your onboarding journey. Explore the available support channels and learning resources.
